@@ -40,7 +40,6 @@
 // Konsole
 #include "Session.h"
 #include "TerminalCharacterDecoder.h"
-#include "konsole_wcwidth.h"
 
 using namespace Konsole;
 
@@ -225,7 +224,7 @@ void Filter::getLineColumn(int position, int &startLine, int &startColumn)
 
         if (_linePositions->value(i) <= position && position < nextLine) {
             startLine = i;
-            startColumn = string_width(buffer()->mid(_linePositions->value(i),
+            startColumn = Character::stringWidth(buffer()->mid(_linePositions->value(i),
                                                      position - _linePositions->value(i)));
             return;
         }
@@ -574,9 +573,9 @@ static QString createFileRegex(const QStringList &patterns, const QString &fileP
     QStringList prefixes = patterns.filter(QRegularExpression(QStringLiteral("^") + filePattern + QStringLiteral("+\\*$")));
     QStringList fullNames = patterns.filter(QRegularExpression(QStringLiteral("^") + filePattern + QStringLiteral("$")));
 
-    suffixes.replaceInStrings(QStringLiteral("*"), QStringLiteral(""));
+    suffixes.replaceInStrings(QStringLiteral("*"), QString());
     suffixes.replaceInStrings(QStringLiteral("."), QStringLiteral("\\."));
-    prefixes.replaceInStrings(QStringLiteral("*"), QStringLiteral(""));
+    prefixes.replaceInStrings(QStringLiteral("*"), QString());
     prefixes.replaceInStrings(QStringLiteral("."), QStringLiteral("\\."));
 
     return QString(
