@@ -97,8 +97,6 @@ public:
      */
     void setMenuBarInitialVisibility(bool visible);
 
-    void setNavigationStyleSheetFromFile(const QUrl &styleSheetFile);
-
 Q_SIGNALS:
 
     /**
@@ -121,6 +119,7 @@ Q_SIGNALS:
 protected:
     // Reimplemented for internal reasons.
     void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
 
     // reimplemented from KMainWindow
     bool queryClose() Q_DECL_OVERRIDE;
@@ -169,8 +168,8 @@ private:
     void removeMenuAccelerators();
     void restoreMenuAccelerators();
     void setupActions();
-    void setupMainWidget();
     QString activeSessionDir() const;
+    void triggerAction(const QString &name) const;
 
     /**
      * Returns the bookmark handler associated with this window.
