@@ -181,21 +181,19 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
     }
 
     // load the profile
-    auto reader = new ProfileReader();
+    ProfileReader reader;
 
     Profile::Ptr newProfile = Profile::Ptr(new Profile(fallbackProfile()));
     newProfile->setProperty(Profile::Path, path);
 
     QString parentProfilePath;
-    bool result = reader->readProfile(path, newProfile, parentProfilePath);
+    bool result = reader.readProfile(path, newProfile, parentProfilePath);
 
     if (!parentProfilePath.isEmpty()) {
         Profile::Ptr parentProfile = loadProfile(parentProfilePath);
         newProfile->setParent(parentProfile);
     }
 
-    delete reader;
-
     if (!result) {
         qCDebug(KonsoleDebug) << "Could not load profile from " << path;
         return Profile::Ptr();
@@ -209,14 +207,13 @@ Profile::Ptr ProfileManager::loadProfile(const QString& shortPath)
 }
 QStringList ProfileManager::availableProfilePaths() const
 {
-    auto reader = new ProfileReader();
+    ProfileReader reader;
 
     QStringList paths;
-    paths += reader->findProfiles();
+    paths += reader.findProfiles();
 
     qStableSort(paths.begin(), paths.end(), stringLessThan);
 
-    delete reader;
     return paths;
 }
 
@@ -340,15 +337,14 @@ Profile::Ptr ProfileManager::fallbackProfile() const
 
 QString ProfileManager::saveProfile(Profile::Ptr profile)
 {
-    auto writer = new ProfileWriter();
+    ProfileWriter writer;
 
-    QString newPath = writer->getPath(profile);
+    QString newPath = writer.getPath(profile);
 
-    if (!writer->writeProfile(newPath, profile)) {
+    if (!writer.writeProfile(newPath, profile)) {
         KMessageBox::sorry(nullptr,
                            i18n("Konsole does not have permission to save this profile to %1", newPath));
     }
-    delete writer;
 
     return newPath;
 }
@@ -514,10 +510,10 @@ void ProfileManager::setDefaultProfile(Profile::Ptr profile)
 void ProfileManager::saveDefaultProfile()
 {
     QString path = _defaultProfile->path();
-    auto writer = new ProfileWriter();
+    ProfileWriter writer;
 
     if (path.isEmpty()) {
-        path = writer->getPath(_defaultProfile);
+        path = writer.getPath(_defaultProfile);
     }
 
     QFileInfo fileInfo(path);
@@ -525,8 +521,6 @@ void ProfileManager::saveDefaultProfile()
     KSharedConfigPtr appConfig = KSharedConfig::openConfig();
     KConfigGroup group = appConfig->group("Desktop Entry");
     group.writeEntry("DefaultProfile", fileInfo.fileName());
-
-    delete writer;
 }
 
 QSet<Profile::Ptr> ProfileManager::findFavorites()
@@ -575,6 +569,14 @@ void ProfileManager::loadShortcuts()
         _shortcuts.insert(shortcut, data);
     }
 }
+
+QString ProfileManager::normalizePath(const QString& path) const {
+    QFileInfo fileInfo(path);
+    const QString location = QStandardPaths::locate(
+            QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + fileInfo.fileName());
+    return (!fileInfo.isAbsolute()) || location.isEmpty() ? path : fileInfo.fileName();
+}
+
 void ProfileManager::saveShortcuts()
 {
     KSharedConfigPtr appConfig = KSharedConfig::openConfig();
@@ -584,30 +586,27 @@ void ProfileManager::saveShortcuts()
     QMapIterator<QKeySequence, ShortcutData> iter(_shortcuts);
     while (iter.hasNext()) {
         iter.next();
-
         QString shortcutString = iter.key().toString();
-
-        // if the profile path in "Profile Shortcuts" is an absolute path,
-        // take the profile name
-        QFileInfo fileInfo(iter.value().profilePath);
-        QString profileName;
-        if (fileInfo.isAbsolute()) {
-            // Check to see if file is under KDE's data locations.  If not,
-            // store full path.
-            const QString location = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                                            QStringLiteral("konsole/") + fileInfo.fileName());
-            if (location.isEmpty()) {
-                profileName = iter.value().profilePath;
-            } else  {
-                profileName = fileInfo.fileName();
-            }
-        } else {
-            profileName = iter.value().profilePath;
-        }
-
+        QString profileName = normalizePath(iter.value().profilePath);
         shortcutGroup.writeEntry(shortcutString, profileName);
     }
 }
+
+
+void ProfileManager::saveFavorites()
+{
+    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
+    KConfigGroup favoriteGroup = appConfig->group("Favorite Profiles");
+
+    QStringList paths;
+    foreach(const Profile::Ptr& profile, _favorites) {
+        Q_ASSERT(_profiles.contains(profile) && profile);
+        paths << normalizePath(profile->path());
+    }
+    favoriteGroup.writeEntry("Favorites", paths);
+}
+
+
 void ProfileManager::setShortcut(Profile::Ptr profile ,
                                  const QKeySequence& keySequence)
 {
@@ -661,37 +660,6 @@ void ProfileManager::loadFavorites()
 
     _loadedFavorites = true;
 }
-void ProfileManager::saveFavorites()
-{
-    KSharedConfigPtr appConfig = KSharedConfig::openConfig();
-    KConfigGroup favoriteGroup = appConfig->group("Favorite Profiles");
-
-    QStringList paths;
-    foreach(const Profile::Ptr& profile, _favorites) {
-        Q_ASSERT(_profiles.contains(profile) && profile);
-
-        QFileInfo fileInfo(profile->path());
-        QString profileName;
-
-        if (fileInfo.isAbsolute()) {
-            // Check to see if file is under KDE's data locations.  If not,
-            // store full path.
-            const QString location = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konsole/") + fileInfo.fileName());
-
-            if (location.isEmpty()) {
-                profileName = profile->path();
-            } else {
-                profileName = fileInfo.fileName();
-            }
-        } else {
-            profileName = profile->path();
-        }
-
-        paths << profileName;
-    }
-
-    favoriteGroup.writeEntry("Favorites", paths);
-}
 
 QList<QKeySequence> ProfileManager::shortcuts()
 {
